#version 430 core
// following this tutorial: https://learnopengl.com/Advanced-OpenGL/Framebuffers
out vec4 FragColor;
  
in vec2 TexCoords;

uniform sampler2D screenTexture;
uniform sampler2D normalsTexture;

const float offset = 1.0 / 600.0;

const vec2 offsets[9] = vec2[](
        vec2(-offset,  offset), // top-left
        vec2( 0.0f,    offset), // top-center
        vec2( offset,  offset), // top-right
        vec2(-offset,  0.0f),   // center-left
        vec2( 0.0f,    0.0f),   // center-center
        vec2( offset,  0.0f),   // center-right
        vec2(-offset, -offset), // bottom-left
        vec2( 0.0f,   -offset), // bottom-center
        vec2( offset, -offset)  // bottom-right    
    );

// laplace D2 kernel
const float kernel[9] = float[](
        1, 1, 1,
        1,-8, 1,
        1, 1, 1
    );

void main()
{ 
    vec3 samples[9];
    for(int i = 0; i < 9; i++)
    {
        samples[i] = vec3(texture(normalsTexture, TexCoords.xy + offsets[i]));
    }
    vec3 currentPixel = vec3(0.0);
    for(int i = 0; i < 9; i++)
        currentPixel += samples[i] * kernel[i];

    if(length(currentPixel) > 0.5){
        FragColor = vec4(0.05, 0.05, 0.05, 1.0);
    }else {
        FragColor = texture(screenTexture, TexCoords);
    }
    
}
